@@ -30,13 +30,11 @@ class MailImporter::FilterSylpheedPrivate
 {
 public:
     FilterSylpheedPrivate()
-        : mImportDirDone(0)
-        , mTotalDir(0)
     {
     }
 
-    int mImportDirDone;
-    int mTotalDir;
+    int mImportDirDone = 0;
+    int mTotalDir = 0;
 };
 /** Default constructor. */
 FilterSylpheed::FilterSylpheed()
@@ -58,6 +56,15 @@ FilterSylpheed::~FilterSylpheed()
     delete d;
 }
 
+QString FilterSylpheed::isMailerFound()
+{
+    QDir directory(FilterSylpheed::defaultSettingsPath());
+    if (directory.exists()) {
+        return i18nc("name of sylpheed application", "Sylpheed");
+    }
+    return {};
+}
+
 QString FilterSylpheed::defaultSettingsPath()
 {
     return QDir::homePath() + QLatin1String("/.sylpheed-2.0/");
